@@ -28,6 +28,9 @@ TICKET_CONNECTOR_CONFIG_DEFAULT = {
         'SessionCreate': {'RequestMethod': 'POST',
                           'Route': '/Session',
                           'Result': 'SessionID'},
+        'AccessTokenCreate': {'RequestMethod': 'POST',
+                              'Route': '/Session',
+                              'Result': 'AccessToken'},
         'SessionGet': {'RequestMethod': 'GET',
                        'Route': '/Session/:SessionID',
                        'Result': 'SessionData'},
@@ -879,6 +882,7 @@ class Client(object):
         user_agent (str): optional HTTP UserAgent string
         webservice_path (str): OTRS REST Web Service Path part - defaults to
             "/otrs/nph-genericinterface.pl/Webservice/"
+        use_legacy_sessions (bool): if True, use sessions compatibility for OTRS < V8
 
     """
 
@@ -899,7 +903,9 @@ class Client(object):
                  client_auth_cert=None,
                  customer_user=False,
                  user_agent=None,
-                 webservice_path="/otrs/nph-genericinterface.pl/Webservice/"):
+                 webservice_path="/otrs/nph-genericinterface.pl/Webservice/",
+                 use_legacy_sessions=False
+                 ):
 
         if not baseurl:
             raise ArgumentMissingError("baseurl")
@@ -970,6 +976,8 @@ class Client(object):
 
         self.user_agent = user_agent
 
+        self.use_legacy_sessions = use_legacy_sessions
+
         # credentials
         self.username = username
         self.password = password
@@ -979,6 +987,20 @@ class Client(object):
         self.result_json = None
         self.result = []
 
+    """
+    Returns the correct session key to look for/send based
+    on the current session compatibility level
+    for legacy sessions (< OTRS V8) this returns 'SessionID'
+    from V8 onwards this returns 'AccessToken'
+    """
+
+    @property
+    def _session_key(self):
+        if self.use_legacy_sessions:
+            return 'SessionID'
+        else:
+            return 'AccessToken'
+
     """
     GenericInterface::Operation::Session::SessionCreate
         * session_check_is_valid
@@ -1014,7 +1036,7 @@ class Client(object):
             raise ArgumentMissingError("session_id")
 
         # TODO 2016-04-13 (RH): Is there a nicer way to check whether session is valid?!
-        payload = {"SessionID": session_id}
+        payload = {self._session_key: session_id}
 
         response = self._send_request(payload, data_id=self.session_validation_ticket_id)
         return self._parse_and_validate_response(response)
@@ -1032,7 +1054,10 @@ class Client(object):
             Uses HTTP Method: POST
 
         """
-        self.operation = "SessionCreate"
+        if self.use_legacy_sessions:
+            self.operation = "SessionCreate"
+        else:
+            self.operation = "AccessTokenCreate"
 
         if self.customer_user:
             payload = {
@@ -1045,10 +1070,18 @@ class Client(object):
                 "Password": self.password
             }
 
-        if not self._parse_and_validate_response(self._send_request(payload)):
+        response = self._send_request(payload)
+        try:
+            if not self._parse_and_validate_response(response):
+                return False
+        except ResponseParseError:
+            if not self.use_legacy_sessions:
+                log.warning("AccessTokenCreate failed, retrying using legacy session")
+                self.use_legacy_sessions = True
+                return self.session_create()
             return False
 
-        self.session_id_store.value = self.result_json['SessionID']
+        self.session_id_store.value = self.result_json[self._session_key]
         return True
 
     def session_get(self, session_id=None):
@@ -1066,7 +1099,7 @@ class Client(object):
         if not session_id:
             raise ArgumentMissingError("session_id")
 
-        payload = {"SessionID": session_id}
+        payload = {self._session_key: session_id}
 
         response = self._send_request(payload, data_id=session_id)
         return self._parse_and_validate_response(response)
@@ -1105,7 +1138,7 @@ class Client(object):
             raise SessionCreateError("Failed to create a Session ID!")
 
         # save new created session_id to file
-        if not self.session_id_store.write(self.result_json['SessionID']):
+        if not self.session_id_store.write(self.result_json[self._session_key]):
             raise IOError("Failed to save Session ID to file!")
         else:
             log.info("Saved new Session ID to file: "
@@ -1157,7 +1190,7 @@ class Client(object):
             raise SessionCreateError("Failed to create a Session ID!")
 
         # save new created session_id to file
-        if not self.session_id_store.write(self.result_json['SessionID']):
+        if not self.session_id_store.write(self.result_json[self._session_key]):
             raise IOError("Failed to save Session ID to file!")
         else:
             log.info("Saved new Session ID to file: "
@@ -1192,7 +1225,7 @@ class Client(object):
                                     "session_restore_or_set_up_new() first")
         self.operation = "TicketCreate"
 
-        payload = {"SessionID": self.session_id_store.value}
+        payload = {self._session_key: self.session_id_store.value}
 
         if not ticket:
             raise ArgumentMissingError("Ticket")
@@ -1255,7 +1288,7 @@ class Client(object):
         self.operation = "TicketGet"
 
         payload = {
-            "SessionID": self.session_id_store.value,
+            self._session_key: self.session_id_store.value,
             "TicketID": "{0}".format(ticket_id),
             "AllArticles": int(articles),
             "Attachments": int(attachments),
@@ -1304,7 +1337,7 @@ class Client(object):
             return []
 
         payload = {
-            "SessionID": self.session_id_store.value,
+            self._session_key: self.session_id_store.value,
             "TicketID": ','.join([str(item) for item in ticket_id_list]),
             "AllArticles": int(articles),
             "Attachments": int(attachments),
@@ -1393,7 +1426,7 @@ class Client(object):
                                     "session_restore_or_set_up_new() first")
         self.operation = "TicketSearch"
         payload = {
-            "SessionID": self.session_id_store.value,
+            self._session_key: self.session_id_store.value,
         }
 
         if dynamic_fields:
@@ -1464,7 +1497,7 @@ class Client(object):
                                     "session_restore_or_set_up_new() first")
         self.operation = "TicketUpdate"
 
-        payload = {"SessionID": self.session_id_store.value, "TicketID": ticket_id}
+        payload = {self._session_key: self.session_id_store.value, "TicketID": ticket_id}
 
         if article:
             article.validate()
@@ -1533,7 +1566,7 @@ class Client(object):
         self.operation = "LanguageList"
 
         payload = {
-            "SessionID": self.session_id_store.value
+            self._session_key: self.session_id_store.value
         }
 
         result = self._parse_and_validate_response(self._send_request(payload))
@@ -1550,7 +1583,7 @@ class Client(object):
         self.operation = "PublicCategoryList"
 
         payload = {
-            "SessionID": self.session_id_store.value
+            self._session_key: self.session_id_store.value
         }
 
         result = self._parse_and_validate_response(self._send_request(payload))
@@ -1577,7 +1610,7 @@ class Client(object):
         self.operation = "PublicFAQGet"
 
         payload = {
-            "SessionID": self.session_id_store.value
+            self._session_key: self.session_id_store.value
         }
 
         if not item_ids:
@@ -1629,7 +1662,7 @@ class Client(object):
         self.operation = "PublicFAQSearch"
 
         payload = {
-            "SessionID": self.session_id_store.value,
+            self._session_key: self.session_id_store.value,
         }
 
         if what:
@@ -1688,7 +1721,7 @@ class Client(object):
         self.operation = "LinkAdd"
 
         payload = {
-            "SessionID": self.session_id_store.value,
+            self._session_key: self.session_id_store.value,
             "SourceObject": src_object_type,
             "SourceKey": int(src_object_id),
             "TargetObject": dst_object_type,
@@ -1731,7 +1764,7 @@ class Client(object):
         self.operation = "LinkDelete"
 
         payload = {
-            "SessionID": self.session_id_store.value,
+            self._session_key: self.session_id_store.value,
             "Object1": src_object_type,
             "Key1": int(src_object_id),
             "Object2": dst_object_type,
@@ -1766,7 +1799,7 @@ class Client(object):
         self.operation = "LinkDeleteAll"
 
         payload = {
-            "SessionID": self.session_id_store.value,
+            self._session_key: self.session_id_store.value,
             "Object": object_type,
             "Key": int(object_id)
         }
@@ -1808,7 +1841,7 @@ class Client(object):
         self.operation = "LinkList"
 
         payload = {
-            "SessionID": self.session_id_store.value,
+            self._session_key: self.session_id_store.value,
             "Object": src_object_type,
             "Key": int(src_object_id),
             "State": state
@@ -1843,7 +1876,7 @@ class Client(object):
         self.operation = "PossibleLinkList"
 
         payload = {
-            "SessionID": self.session_id_store.value,
+            self._session_key: self.session_id_store.value,
         }
 
         if self._parse_and_validate_response(self._send_request(payload)):
@@ -1874,7 +1907,7 @@ class Client(object):
         self.operation = "PossibleObjectsList"
 
         payload = {
-            "SessionID": self.session_id_store.value,
+            self._session_key: self.session_id_store.value,
             "Object": object_type,
         }
 
@@ -1909,7 +1942,7 @@ class Client(object):
         self.operation = "PossibleTypesList"
 
         payload = {
-            "SessionID": self.session_id_store.value,
+            self._session_key: self.session_id_store.value,
             "Object1": src_object_type,
             "Object2": dst_object_type,
         }
